<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Fermi (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Maletendi</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Etendi</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Forsendi Averton</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln vorto</numerusform>
            <numerusform>%Ln vortoj</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuto</numerusform>
            <numerusform>%Ln minutoj</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% de %Ln minuto</numerusform>
            <numerusform>%L1% de %Ln minutoj</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% de %Ln vorto</numerusform>
            <numerusform>%L1% de %Ln vortoj</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Ĉiutaga Progreso</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Plej longa serio</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Aktuala serio</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N-A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n tago</numerusform>
            <numerusform>%n tagoj</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% de ĉiutaga celo</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Agordi Lingvon</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sentitole %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Nurlegebla)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Pardonu</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Ne eblis konservi &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Konservi dosieron kiel...</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Ne eblis anstataŭigi &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Renomi Dosieron</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Ne eblis renomi &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Reŝargi la Dosieron?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Reŝargi la dosieron &apos;%1&apos; el disko?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Ĉiuj nekonservitaj ŝanĝoj perdiĝos.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Reŝargi</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sentitole %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Konservi kiel plata teksto ne konservos ĉiun tekstaranĝon. Ne konservu tekstaranĝon?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Dosiero Ŝanĝiĝis</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>La dosiero &apos;%1&apos; ŝanĝiĝis de alia programaro.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Ĉu vi volas reŝargi la dosieron?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Reŝargi</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Malatenti</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Dosiero Foriĝis</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>La dosiero %1 foriĝis de alia programaro.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Ĉu vi volas konservi aŭ fermi la dosieron?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Ne eblis malfermi arĥivon.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Serĉi por:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Anstataŭigi kun:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Malatenti usklon</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Nur tutaj vortoj</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Regulesprimoj</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Serĉi supren</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Serĉi malsupren</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trovi</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Anstataŭigi</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Anstataŭigi ĉiu&amp;jn</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Trovi</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Anstataŭigi</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Anstataŭigi %n aperon?</numerusform>
            <numerusform>Anstataŭigi %n aperojn?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Pardonu</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Frazero ne troviĝis.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Teksto</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Plata Teksto</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Ĉiuj Dosieroj</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Ĉiuj Subtenataj Dosieroj</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Kontroli Literumadon...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Ne sugestoj troviĝis)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Malfermi Bildon</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bildoj</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Elekti lingvon de aplikaĵo:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Lingvo de Sistemo&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Noto</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bonvolu relanĉi ĉi tiun aplikaĵon por la lingva ŝanĝo efiki.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Ne eblis malfermi arĥivon.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ĝenerale</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiko</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Ilobreto</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Literumada Kontrolo</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Elekti Vortaron</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Pardonu</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Ne eblis malfermi arĥivon.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>La arĥivo ne enhavas uzeblan vortaron.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Fulmoklavoj</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Unu aŭ pluraj fulmoklavoj konfliktas. Ĉu vi volas daŭri?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>La vortaro &quot;%1&quot; jam ekzistas. Ĉu vi volas anstataŭigi ĝin?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Ĉiutaga Celo</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenio</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minutoj:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Vortoj:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Redaktado</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Ĉiam vertikale centri</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Bloka enmeta kursoro</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Glataj tajparoj</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Skribmaŝinaj sonoj</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Inteligentaj citiloj:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Duoble</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Unuoble</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scenoj</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Dividanto:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Konservante</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Memori kursoran pozicion</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Vortnombrado</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Paĝnombrado</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Alinenombrado</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Signonombrado</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Signoj:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Alineoj:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Vortnombrada Algoritmo</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Rekomencigi ĉiutagan progreson por hodiaŭ?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Skribi bajtordo-marko en platatekstajn dosierojn</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Defaŭlta dosierformo:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Rekomencigi Hodiaŭ</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historio</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Memori historion</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Montri seriojn</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minimuma progreso por serioj:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Detekti vortlimojn</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Dividi signonombradon per ses</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Nombri ĉiun literon kiel vorton</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Paĝnombrada Algoritmo</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stilo</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Nur Bildsimboloj</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Nur Teksto</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Teksto Flanke de Bildsimboloj</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Teksto Malsupre de Bildsignoj</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Pozicio de Teksto</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Agoj</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Movi Supren</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Movi Malsupren</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Aldoni Apartigilon</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komando</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Fulmoklavo</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ago</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Kontroli literumadon dum vi tajpas</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Malatenti vortojn da MAJUSKLOJ</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Malatenti vortojn kun numeroj</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Lingvo</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Persona Vortaro</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Ne subtenata RTF dosiero.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Neatendite atingis dosierfinon.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Malsupren</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Movi Scenojn Supren</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Supren</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Baskuligi Liston da Scenoj</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Montri liston da scenoj (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Kaŝi liston da scenoj (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtri</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Movi Scenojn Malsupren</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Regrandigi liston da scenoj</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Defaŭlto</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Administri Seancojn</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;eancoj</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duobligi</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Ŝanĝi Al</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova seanco</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Duobligi Seancon</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Renomi Seancon</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Forigi elektitan seancon?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Seanca nomo:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Pardonu</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>La petita seanca nomo estas jam uzata.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nova...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Administri...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Vakigi</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Rekomencigi Defaŭlten</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Fulmoklavo:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Anstataŭigante citilojn...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Bonvolu Atendi</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Kontroli Literumadon</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Aldoni</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Malatenti</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Malatenti ĉ&amp;iujn</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>Ŝa&amp;nĝi</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Ŝanĝi ĉiu&amp;jn</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Ne en vortaro:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Ŝanĝi al:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Kontrolante literumadon...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nuligi</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Bonvolu atendi</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Daŭri kontroli dekomence?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Literumada kontrolo finfaris.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Simboloj</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Lastatempe uzitaj simboloj</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Ĉiuj simboloj</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detaloj</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nomo:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Enmeto</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blokoj</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Skriboj</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Sentitole %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nomo:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Neniu Bildo</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Kahelita</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrita</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Streĉita</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Skalita</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Zomita</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opakeco:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Pozicio:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Larĝo:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Rondaj Tekstfonaj Anguloj</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Duondiametro:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Malfokusi Tekstfonon</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Tekstfona Ĵetita Ombro</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Vertikala Deŝovo:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Marĝenoj</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Fenestro:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Paĝo:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Krei krommarĝenon sur la unua lineo</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Supre:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Malsupre:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Redakti Etoson</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Fenestra Fono</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Koloro:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Bildo:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>bilderoj</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Maldekstre</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Tekstfono</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dekstre</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksto</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Tajparo:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Misortografiita:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Interlinea Distanco</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Unuoble</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 Lineoj</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Duoble</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporcie</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Alto:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Interalinea Distanco</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Larĝo de Tabo:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nova etoso</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Etosoj</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Defaŭlto</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Mola Bluso</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Malnoveca stilo</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Kosmaj Sonĝoj</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Skribtablo</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nov</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duobligi</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Propra</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redakti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Enporti</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Elporti</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Forigi etoson &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Etosoj (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Elporti Etoson</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Elporti Etoson</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Forigi tempmezurilon?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Vortoj:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paĝoj:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Alineoj:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Signoj:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Agordi Prokraston</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Agordi Tempon</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Prokrasto:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tempo:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarmo</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Noto:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redakti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Neniu funkcianta tempmezurilo</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Tempmezuriloj</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Lastatempe</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Rezigni redakton de tempmezuriloj?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Ŝargante etosojn</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Ŝargante sonojn</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sentitole</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Malfermi Dosieron</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Pri FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Simpla tutekrana tekstoprilaborilo</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Kopirajto &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Eldonita per la &lt;a href=%1&gt;GPL 3&lt;/a&gt; permesilo</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Uzas bildsimbolojn de la &lt;a href=%1&gt;Oxygen&lt;/a&gt; bildsimbola etoso</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Uzata per la &lt;a href=%1&gt;LGPL 3&lt;/a&gt; permesilo</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Signoj: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Paĝoj: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Alineoj: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Vortoj: %1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Malfermante %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sentitole %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Listi ĉiujn dokumentojn</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Ŝanĝi al Sekva Dokumento</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Ŝanĝi al Antaŭa Dokumento</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Ŝanĝi al Unua Dokumento</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Ŝanĝi al Lasta Dokumento</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Ŝanĝi al Dokumento %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Ŝargante agordojn</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Kriza kaŝmemoro ne skribeblas.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Averto</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter ne malŝatis pure.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Restaŭri de la kriza kaŝmemoro?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Ne eblis malfermi kelkajn dosierojn.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Kelkaj dosieroj malfermis nurlegeble.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; estas plinova ol la kaŝmemorita kopio.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Anstataŭigi la novan dosieron?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Konservi Ŝanĝojn?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Konservi ŝanĝojn en la dosieron &apos;%1&apos; antaŭ fermi?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Viaj ŝanĝoj estos perditaj, se vi ne konservas ilin.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Ne eblis ŝargi skribmaŝinajn sonojn.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Dosiero</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Malfermi...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Reŝar&amp;gi</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Konservi</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Konservi kie&amp;l...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Renomi...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Konservi ĉiu&amp;jn</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Administri Seancojn</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova seanco</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Presi...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermi...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Ĉ&amp;esi</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Redakti</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Malfari</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Refari</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>E&amp;tondi</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopii</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>E&amp;nmeti</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Enmeti sen&amp;aranĝe</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Elekti ĉi&amp;on</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Elekti &amp;scenon</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>&amp;Aranĝo</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Grasa</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>K&amp;ursiva</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>Subst&amp;reki</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Trast&amp;reki</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Su&amp;pra indico</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Su&amp;ba indico</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Ĝisrandigi &amp;maldekstren</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>&amp;Centrigi</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Ĝisrandigi &amp;dekstren</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Ĝisrandigi</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Ma&amp;lgrandigi krommarĝenon</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Grandigi Krommarĝenon</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Demaldekstra Bloko</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Dedekstra blo&amp;ko</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Iloj</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Trovi...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Trovi &amp;sekve</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Tro&amp;vi antaŭe</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Anstataŭigi...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Inteligentaj Citiloj</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Ĝisdatigi Dokumenton</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Ĝisdatigi Elekton</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Literumado...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Agordi &amp;lingvon...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>Tempomezuriloj...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Simboloj</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>Ĉiutaga Progreso</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Montri Ilobreton</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Montri Menuajn Bildsimbolojn</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Fokusita Teksto</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Tutekrane</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Plejetigi</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>Etosoj...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>A&amp;gordoj...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Ne Fokuso</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Unulinea Fokuso</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Trilinea Fokuso</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>Alineo</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Fokusi Alineon</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Helpo</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Lingvo de la aplikaĵo...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Kelkaj dosieroj ne estis subtenitaj kaj ne povis malfermiĝi.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>Neniu</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Unu Lineo</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>Tri Lineo</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Pri</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Pri &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Titolo</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Titolo &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Titolo &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Titolo &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Titolo &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Titolo &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Titolo &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normala</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
